@@ -31,6 +31,9 @@ pysetup=pybuild.pysetup()
 pysetup.dirmain="{0}{1}/".format(config.gmodules_,name)
 pysetup.dependencies=['vmp','vmp_plugin']
 
+def description():
+    return "description module"
+    
 def install():
     pybuild.pybuild(pysetup)
 
