@@ -16,12 +16,13 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 11/12/2018
+#Date last Update : 05/04/2024
 
 import vmpsys    as sys
 import vmputils  as utils
 import vmpconfig as config
 import vmpcheck  as check
+import vmpbuild   as build
 
 config.pyenv()
 
@@ -104,6 +105,7 @@ help_=[
        ("To Install module usage:","-m {name}"),
        ("To Get modules list:","-ml"),
        ("To Get module description:","-md {name}"),
+       ("Build symbolic link external lib within the vampire environment(see directory vmp-?/{0}):".format(config.glib_),"-l {libname(not .so extension)} {externalpath}"),
        ("To install framework main doc","-dm"),
        ("To Install framework c++ doc","-dc"),
        ("To Install framework python doc","-dp"),
@@ -154,7 +156,7 @@ if __name__ == "__main__":
       config.pyhome_add(config.gsoftware_path(args[1]))
       try:
         desc=software_desc(config.gsoftware_path(args[1]))
-        sys.stdout("Software \'{0}\' description:\n{1}\n".format(args[1],desc))
+        sys.stdout("\nSoftware \'{0}\' description:\n[{1}]\n\n".format(args[1],desc))
         sys.exit_ok()
       except Exception as e:
         sys.msg_failure("Software description \'{0}\'".format(args[1]),str(e))
@@ -172,9 +174,15 @@ if __name__ == "__main__":
       config.pyhome_add(config.gmodule_main_(args[1]))
       try:
         desc=software_desc(config.gmodule_main_(args[1]))
-        sys.stdout("Module \'{0}\' description:\n{1}\n".format(args[1],desc))
+        sys.stdout("\nModule \'{0}\' description:\n[{1}]\n\n".format(args[1],desc))
+        sys.stdout("To read the detailed documentation of the modules use the software vampiria\n\n")
         sys.exit_ok()
       except Exception as e:
         sys.msg_failure("Module description \'{0}\'".format(args[1]),str(e))
+  elif l == 3:
+    if args[0] == '-l':
+      if sys.search_cmd("ln --help".split()):
+        build.symlink_lib_build(args[1],args[2])
+        sys.exit_ok()
   utils.help(config.installer_,help_)
 
