@@ -91,18 +91,14 @@ def cclear(setup):
    
 ##Build symbolic link external lib<BR>
 #
-#@param libname link name<BR>
-#@param example example string in output
-def symlink_lib_build(libname,example):
-  sys.stdout("Insert path source link[ex:{0}]:".format(example));
-  value = sys.stdin()
-  if value == "":
-    sys.msg_failure("Build symlink {0}".format(libname),"Empty input received")
-  libpath="{0}{1}.so".format(sys.path(config.glib_),libname)
-  if not sys.isfile(value):
-    sys.msg_failure("Build symlink {0}->{1}".format(value,libpath),"invalid input value")
-  sys.system("ln -sf {0} \"{1}\"".format(value,libpath))
-  sys.msg_ok("Build symlink {0}->{1}".format(value,libpath))
+#@param libname library name within vmp<BR>
+#@param libpath system library path to link 
+def symlink_lib_build(libname,libpath):
+  ipath="{0}{1}.so".format(sys.path(config.glib_),libname)
+  if not sys.isfile(libpath):
+    sys.msg_failure("Library file '{0}'".format(libpath),"not found")
+  sys.system("ln -sf {0} \"{1}\"".format(libpath,ipath))
+  sys.msg_ok("Build symlink {0}->{1}".format(libpath,ipath))
 
 ##Deletes symbolic link external lib<BR>
 #
