@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 14/10/2023
+#Date last Update : 09/04/2024
 
 import vmpsys as sys
 
@@ -33,7 +33,7 @@ webpage_="http://www.ragnu.it"
 license_="GPL3"
 
 ##Vampiria version
-version_="0.5.1"
+version_="0.6.2"
 
 ##Vampiria release type
 release_="alpha"
@@ -55,35 +55,38 @@ def config_path(path):
 
 ##Framework directory path section
 
+##Framework path
+frmwk_="framework/"
+
 ##Framework lib path
-fwlib_="framework/lib/"
+fwlib_="{0}lib/".format(frmwk_)
 
 ##Framework c++ src path
-fwsrc_="framework/src/"
+fwsrc_="{0}src/".format(frmwk_)
 
 ##Framework python lib path
-fwpylib_="framework/python/"
+fwpylib_="{0}python/".format(frmwk_)
 
 ##Framework python lib shared object
-fwpylibso_="framework/pylib/"
+fwpylibso_="{0}pylib/".format(frmwk_)
 
 ##Framework main path
-fwmain_="framework/main/"
+fwmain_="{0}main/".format(frmwk_)
 
 ##Framework python main executable
 fwmainexe_="vmpmain.py"
 
 ##Installer path
-installer_="framework/main/install.py"
+installer_="{0}main/install.py".format(frmwk_)
 
 ##Uninstaller path
-uninstaller_="framework/main/uninstall.py"
+uninstaller_="{0}main/uninstall.py".format(frmwk_)
 
 ##Framework doc path
-fwdoc_="framework/doc/lib/"
+fwdoc_="{0}doc/lib/".format(frmwk_)
 
 ##Framework dtd path
-fwdtd_="framework/dtd/"
+fwdtd_="{0}dtd/".format(frmwk_)
 
 ##General directory path section
 
@@ -287,6 +290,7 @@ configlist_= ["/*Config file autogenerate from install*/",
               "#define VLICENSE            \"{0}\"".format(license_),
               "#define VVERSION            \"{0}_{1}\"\n".format(version_,release_),
               "#define VPATH               \"{0}\"".format(root_),
+              "#define VFRMWK              \"{0}\"".format(sys.path(frmwk_)),
               "#define VEXEC               \"{0}\"".format(sys.path(gexec_)),
               "#define VLIB                \"{0}\"".format(sys.path(glib_)),
               "#define VCACHE              \"{0}\"".format(sys.path(gcache_)),
