@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 31/12/2019
+#Date last Update : 15/03/2024
 
 import vmpsys    as sys
 import vmpconfig as config
@@ -146,7 +146,7 @@ pylibs_[plugin.name]=plugin
 json=pylib()
 json.name='vmp_json'
 json.cbuild()
-json.setup.files=[('./',['json_','jdata_','jlist_','jtable_','japi_','jrp_'])]
+json.setup.files=[('./',['json_','jdata_','jlist_','jtable_','japi_','jrp_','status_'])]
 json.setup.dependencies=['vmp','pylib','json','net','packet']
 pylibs_[json.name]=json
 
