@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 24/01/2023
+#Date last Update : 01/03/2024
 
 ##@package vmp
 #
@@ -39,7 +39,9 @@ from vmp_ import RANDMAX   as RANDMAX
 from vmp_ import env as env
 from vmp_ import Buf as Buf
 
-from vmp_ import except_s  as except_s
+from vmp_ import except_s     as except_s
+from vmp_ import get_errno    as get_errno
+from vmp_ import value_errno  as value_errno
 
 from vmp_ import init               as init
 from vmp_ import is_debug_mode      as is_debug_mode
