@@ -36,6 +36,21 @@ struct stub_vampiria_path:public pylib::Generic_def
    }
 };
 
+struct stub_vampiria_frm:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+         vmp::str arg0;
+         if(args.size() == 0)
+             arg0="";
+         else if(args.size() == 1)
+             arg0=args.get<vmp::str>(0);     
+         else
+             return 0;
+         return pylib::Converter<vmp::str>(vmp::env::vampiria_frm(arg0));
+   }
+};
+
 struct stub_vampiria_cache:public pylib::Generic_def
 {
     pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
@@ -153,6 +168,7 @@ void vmp_init_env(pylib::Module module)
     env.def_("license",vmp::env::license);
     env.def_("version",vmp::env::version);
     env.def_with_stub("vampiria_path",stub_vampiria_path());
+    env.def_with_stub("vampiria_frm",stub_vampiria_frm());
     env.def_("vampiria_bin",vmp::env::vampiria_bin);
     env.def_("vampiria_lib",vmp::env::vampiria_lib);
     env.def_with_stub("vampiria_cache",stub_vampiria_cache());
@@ -175,5 +191,6 @@ void vmp_init_env(pylib::Module module)
     env.def_("python_software_main",vmp::env::python_software_main);
     env.def_("python_files_check",vmp::env::python_files_check);
     env.def_("xml_hdr",vmp::env::xml_hdr);
+    env.def_("format_path",vmp::env::format_path);
 }
 
