@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/10/2023
+   Date last update: 26/03/2024
  */
 
 #include "vmp_.h"
@@ -67,12 +67,12 @@ void vmp_init_unicode(pylib::Module module)
     pylib::Module unicode=module.add_submodule("unicode");
 
     // vmp/unicode.h
+    unicode.def_("str_tolower",vmp::unicode::str_tolower);
+    unicode.def_("str_toupper",vmp::unicode::str_toupper);
     unicode.def_("str_split",vmp::unicode::str_split);
     unicode.def_("str_join",vmp::unicode::str_join);
+    unicode.def_("byte_nbit",vmp::unicode::byte_nbit);
     unicode.def_("str_istype",vmp::unicode::str_istype);
-    unicode.def_("str_isdigit",vmp::unicode::str_isdigit);
-    unicode.def_("str_isxdigit",vmp::unicode::str_isxdigit);
-    unicode.def_("str_isreal",vmp::unicode::str_isreal);
     unicode.def_("str_todigit",vmp::unicode::str_todigit);
     unicode.def_("str_todigit_range",vmp::unicode::str_todigit_range);
     unicode.def_("str_toreal",vmp::unicode::str_toreal);
@@ -98,6 +98,7 @@ void vmp_init_unicode(pylib::Module module)
     unicode.def_("str_invector",vmp::unicode::str_invector);
     unicode.def_("shlex_split",vmp::unicode::shlex_split);
     unicode.def_("shlex_join",vmp::unicode::shlex_join);
+    unicode.def_("str_toindex_list",vmp::unicode::str_toindex_list);
     unicode.def_("b64_encode",vmp::unicode::b64_encode);
     unicode.def_("b64_decode",vmp::unicode::b64_decode);
     unicode.def_("utf8_check",vmp::unicode::utf8_check);
