@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 24/01/2023
+   Date last update: 01/02/2024
  */
 
 #include "vmp_.h"
@@ -143,6 +143,8 @@ void vmp_init(pylib::Module module)
 
     //vmp/error.h
     module.def_with_stub("except_s",stub_except_s());
+    module.def_("get_errno",vmp::get_errno);
+    module.def_("value_errno",vmp::value_errno);
 
     //vmp/io.h
     module.def_with_stub("init",stub_init());
