@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 07/10/2023
+   Date last update: 04/04/2024
  */
 
 #include "vmp.h"
@@ -33,7 +33,7 @@
     UCHAR_MIN,UCHAR_MAX,RANDMAX
 */
 /*!
-    Function c++ in vmp/error.h:<BR> except_s()
+    Function c++ in vmp/error.h:<BR> except_s(),get_errno(),value_errno()
 */
 /*!
     Function c++ in vmp/io.h:<BR>init(),is_debug_mode(),id(),io_forced_unlock(),io_recovery_lock(),debug(),
@@ -52,11 +52,11 @@ void vmp_init(pylib::Module module);
 
 //!Python wrapper of the c++ namespace vampiria::vmp::env in vmp.env.(see c++ doc)
 /*!
-    Function c++ in vmp/env.h:<BR>author(),email(),webpage(),license(),version(),vampiria_path(),vampiria_bin(),
+    Function c++ in vmp/env.h:<BR>author(),email(),webpage(),license(),version(),vampiria_path(),vampiria_frm(),vampiria_bin(),
                                   vampiria_lib(),vampiria_cache(),vampiria_home(),software_root(),software_path(),
                                   software_isinstalled(),modules_root(),module_path(),module_main_path(),module_manifest(),
                                   module_isinstalled(),frm_dtd(),python_exe(),python_env(),python_moduleimp(),python_main(),
-                                  python_software_main(),python_files_check(),xml_hdr()
+                                  python_software_main(),python_files_check(),xml_hdr(),format_path()
 */
 void vmp_init_env(pylib::Module module);
 
@@ -71,7 +71,7 @@ void vmp_init_buf(pylib::Module module);
 
 //!Python wrapper of the c++ namespaces vampiria::vmp::fs in vmp.fs.(see c++ doc)
 /*!
-    Function c++ in vmp/lib.h:<BR>unlink_wrap(),format_dirpath(),union_path(),mkdir_wrap(),rmdir_wrap(),chdir_wrap(),
+    Function c++ in vmp/lib.h:<BR>unlink_wrap(),format_dirpath(),union_path(),chmod_wrap(),mkdir_wrap(),rmdir_wrap(),chdir_wrap(),
     isdir(),isrdir(),iswdir(),isxdir(),getcwd_wrap(),listendir(),isfile(),isrfile(),iswfile(),isxfile()
 */
 void vmp_init_fs(pylib::Module module);
@@ -92,9 +92,10 @@ void vmp_init_thread(pylib::Module module);
     Function c++ in vmp/time.h:<BR>vsleep(),time_wrap(),ctime_wrap(),gmtime_wrap()
 */
 /*!
-    Localtime class in vmp/time.h:<BR>Constructor Localtime(time)<BR>
-    Localtime member function list:<BR>sec(),min(),hours(),mday(),wday(),wday_n(),month(),
-                                        month_n(),year()
+    Localtime class in vmp/time.h:<BR>Constructor Localtime(time=0)or Localtime(year,month,day,hour,min,sec)<BR>
+    Localtime member function list:<BR>set(),get_year_days(),set_from_year_day(),next_cronizer(),time(),
+                                       sec(),min(),hour(),mday(),wday(),wday_n(),month(),month_n(),year(),
+                                       ctime(),gmtime(),year_day()
 */
 /*!
     Timer class in vmp/time.h:<BR>Constructor Timer()<BR>
@@ -104,11 +105,12 @@ void vmp_init_time(pylib::Module module);
 
 //!Python wrapper of the c++ namespaces vampiria::vmp::unicode in vmp.unicode.(see c++ doc)
 /*!
-    Function c++ in vmp/unicode.h:<BR>str_split(),str_join(),str_istype(),str_isdigit(),str_isxdigit(),str_isreal(),
-    str_todigit(),str_todigit_range(),str_toreal(),str_toreal_range(),xstr_tobytes(),bytes_toxstr(),bytes_toxstr_hm()
-    str_toxstr(),xstr_tostr(),str_sub(),str_findsub(),str_replace(),str_casecmp(),str_trim(),str_isword(),str_format(),
-    str_format_maxline(),str_format_end(),str_extract_char(),str_remove_duplex(),str_regex(),str_regex_matching(),
-    str_invector(),shlex_join(),shlex_join(),b64_encode(),b64_decode(),utf8_check()
+    Function c++ in vmp/unicode.h:<BR>str_tolower(),str_toupper(),str_split(),str_join(),byte_nbit(),
+    str_istype(),str_todigit(),str_todigit_range(),str_toreal(),
+    str_toreal_range(),xstr_tobytes(),bytes_toxstr(),bytes_toxstr_hm(),str_toxstr(),xstr_tostr(),str_sub(),
+    str_findsub(),str_replace(),str_casecmp(),str_trim(),str_isword(),str_format(),str_format_maxline(),
+    str_format_end(),str_extract_char(),str_remove_duplex(),str_regex(),str_regex_matching(),
+    str_invector(),shlex_split(),shlex_join(),str_toindex_list(),b64_encode(),b64_decode(),utf8_check()
 */
 /*!
     Strtok class in vmp/unicode.h:<BR>Constructor Strtok() or Strtok(content)<BR>
@@ -121,7 +123,7 @@ void vmp_init_unicode(pylib::Module module);
     Const c++ logger loglevel in vmp/utils.h":<BR>
     LOG_NO,LOG_DEBUG,LOG_INFO,LOG_WARN,LOG_ERR<BR>
     Logger class in vmp/utils.h:<BR>Constructor Logger<BR>
-    Logger member function list:<BR>reset(),set(),write()
+    Logger member function list:<BR>reset(),set(),write(),rotate()
 */
 void vmp_init_utils(pylib::Module module);
 
