@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 25/01/2023
+#Date last Update : 08/01/2024
 
 from vmp_event_ import Manager as Manager
 
@@ -31,6 +31,8 @@ from vmp_event_ import simplexui       as simplexui
 from vmp_event_ import SimplexUI       as SimplexUI
 from vmp_event_ import timerui         as timerui
 from vmp_event_ import TimerUI         as TimerUI
+from vmp_event_ import croniterui      as croniterui
+from vmp_event_ import CroniterUI      as CroniterUI
 
 from . import process as process
 
