@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 04/02/2023
+ * Date last update: 09/02/2024
  */
 
 #include "vmp.h"
@@ -30,7 +30,9 @@
 //!Python wrapper of the c++ class vampiria::event::Manager in vmp_event.Manager(see c++ doc)
 /*!
     Manager class in event.h:<BR>Constructor Manager()<BR>
-    Manager member function list:<BR>init(),lock(),unlock(),forced_unlock(),recovery_lock(),time_now(),breakloop(),stop(),loop()
+    Manager member function list:<BR>init(),breakloop(),lock(),unlock(),forced_unlock(),recovery_lock(),cell_update(),
+                                     cell_timewait(),cell_close(),cell_close_ok_spec(),cell_close_err_spec(),cell_closewait(),
+                                     time_now(),cell_alloc(),cell_release(),stop(),loop(),
 */
 void event_init_manager(pylib::Module module);
 
@@ -40,8 +42,9 @@ void event_init_manager(pylib::Module module);
 */
 /*!
     Cell class in event.h:<BR>No Constructor<BR>
-    Cell member function list:<BR>identity(),close(),close_wait(),close_err(),alloc(),release(),ret,str_error(),
-                                  set_timewait(),get_timewait(),get_manager(),setvar(),getvar(),remvar(),all_keys()
+    Cell member function list:<BR>identity(),close(),close_wait(),close_err(),close_err_spec(),alloc(),release(),ret(),
+                                  str_error(),closelevel(),errcode(),set_timewait(),get_timewait(),get_manager(),
+                                  setvar(),getvar(),remvar(),all_keys()
 */
 void event_init_cell(pylib::Module module);
 
@@ -63,10 +66,22 @@ void event_init_inputui(pylib::Module module);
 */
 /*!
    TimerUI Class in event/ui/timerui.h:<BR>Constructor TimerUI(manager)<BR>
-   InputUI member function list:<BR>set_event(),new_timer(),active_timer(),deactive_timer(),get_timeval(),id()
+   TimerUI member function list:<BR>set_event(),new_timer(),active_timer(),deactive_timer(),isactive_timer(),get_timeval(),id()
 */
 void event_init_timerui(pylib::Module module);
 
+//!Python wrapper of the c++ class vampiria::event::CroniterUI in vmp_event.CroniterUI(see c++ doc)
+/*!
+    Wrapper Cell->ui() for input in croniterui(cell)<BR>
+    @return user interface input ui for cell.(The cell must be built with the CroniterUI user interface)
+*/
+/*!
+   CroniterUI Class in event/ui/timerui.h:<BR>Constructor CroniterUI(manager)<BR>
+   CroniterUI member function list:<BR>new_croniter(),active_croniter(),deactive_croniter(),isactive_croniter(),evtname(),
+                                       crontab(),nextcron(),badnext()
+*/
+void event_init_croniterui(pylib::Module module);
+
 //!Python wrapper of the c++ class vampiria::event::SimplexUI in vmp_event.SimplexUI(see c++ doc)
 /*!
     Wrapper Cell->ui() for input in simplexui(cell)<BR>
