@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 18/09/2022
+ * Date last update: 04/04/2024
  */
 
 #include "json_.h"
@@ -117,6 +117,75 @@ struct stub_japi_table:public pylib::Generic_def
      }
 };
 
+struct stub_japi_status:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 1)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            json::japi_status(obj);
+            return pylib::retnone(); 
+        }
+        else if(args.size() == 2)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str id=args.get<vmp::str>(1);
+            json::japi_status(obj,id);
+            return pylib::retnone();
+        }
+        return 0;
+    }
+};
+
+struct stub_japi_status_update:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 3)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str key=args.get<vmp::str>(1);
+            json::JsonObj *data=args.get<json::JsonObj *>(2);
+            json::japi_status_update(obj,key,data);
+            return pylib::retnone(); 
+        }
+        else if(args.size() == 4)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str key=args.get<vmp::str>(1);
+            json::JsonObj *data=args.get<json::JsonObj *>(2);
+            vmp::str id=args.get<vmp::str>(3);
+            json::japi_status_update(obj,key,data,id);
+            return pylib::retnone();
+        }
+        return 0;
+    }
+};
+
+struct stub_japi_status_cancel:public pylib::Generic_def
+{
+    pylib::Objref *def(pylib::Args &args,pylib::KwArgs &kwargs)
+    {
+        if(args.size() == 2)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str key=args.get<vmp::str>(1);
+            json::japi_status_cancel(obj,key);
+            return pylib::retnone(); 
+        }
+        else if(args.size() == 3)
+        {
+            json::JsonObj *obj=args.get<json::JsonObj *>(0);
+            vmp::str key=args.get<vmp::str>(1);
+            vmp::str id=args.get<vmp::str>(2);
+            json::japi_status_cancel(obj,key,id);
+            return pylib::retnone();
+        }
+        return 0;
+    }
+};
+
 void json_japi(pylib::Module module)
 {
     module.def_("japi",json::japi);
@@ -125,5 +194,13 @@ void json_japi(pylib::Module module)
     module.def_("japi_void",json::japi_void);
     module.def_with_stub("japi_list",stub_japi_list());
     module.def_with_stub("japi_table",stub_japi_table());
+    module.def_("japi_oper",json::japi_oper);
+    module.def_("japi_oper_kill",json::japi_oper_kill);
+    module.def_("japi_oper_data",json::japi_oper_data);
+    module.def_("japi_oper_push",json::japi_oper_push);
+    module.def_("japi_oper_close",json::japi_oper_close);
+    module.def_with_stub("japi_status",stub_japi_status());
+    module.def_with_stub("japi_status_update",stub_japi_status_update());
+    module.def_with_stub("japi_status_cancel",stub_japi_status_cancel());
 }
 
