@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 25/09/2022
+#Date last Update : 28/02/2024
 
 ##@package vmp_net
 #
@@ -37,20 +37,46 @@ from vmp_net_ import iface_ipv4_mtu        as iface_ipv4_mtu
 from vmp_net_ import is_macaddress_raw     as is_macaddress_raw
 from vmp_net_ import macaddress_to_buf     as macaddress_to_buf
 from vmp_net_ import macaddress_from_buf   as macaddress_from_buf
+
+from vmp_net_ import CONN_NONE        as CONN_NONE
+from vmp_net_ import CONN_UDP4        as CONN_UDP4
+from vmp_net_ import CONN_UDP6        as CONN_UDP6
+from vmp_net_ import CONN_UDPCONNECT  as CONN_UDPCONNECT
+from vmp_net_ import CONN_UDPPROXY    as CONN_UDPPROXY
+from vmp_net_ import CONN_TCPLISTEN   as CONN_TCPLISTEN
+from vmp_net_ import CONN_TCPSERVER   as CONN_TCPSERVER
+from vmp_net_ import CONN_TCPCLIENT   as CONN_TCPCLIENT
+from vmp_net_ import CONN_TCPPROXY    as CONN_TCPPROXY
+
+from vmp_net_ import conn_strtype     as conn_strtype
+
+from vmp_net_ import ProxyInfo        as ProxyInfo
+
+from vmp_net_ import UDP_MSIZE_DEFAULT     as UDP_MSIZE_DEFAULT
+from vmp_net_ import socket_datagram       as socket_datagram
+from vmp_net_ import socket_stream         as socket_stream
+from vmp_net_ import socket_connect        as socket_connect
+from vmp_net_ import socket_connect_check  as socket_connect_check
+from vmp_net_ import socket_bind           as socket_bind
+from vmp_net_ import socket_listen         as socket_listen
+from vmp_net_ import socket_accept         as socket_accept
+from vmp_net_ import socket_addrlocal      as socket_addrlocal
+from vmp_net_ import socket_addrpeer       as socket_addrpeer
+from vmp_net_ import socket_close          as socket_close
 from vmp_net_ import socket_timeout        as socket_timeout
+from vmp_net_ import socket_recvFrom       as socket_recvFrom
+from vmp_net_ import socket_recv           as socket_recv
+from vmp_net_ import socket_sendTo         as socket_sendTo
+from vmp_net_ import socket_send           as socket_send
+
 from vmp_net_ import tcp_resolve4          as tcp_resolve4
 from vmp_net_ import tcp_resolve6          as tcp_resolve6
 from vmp_net_ import tcp_resolveMX         as tcp_resolveMX
 
 from vmp_net_ import Address             as Address
 from vmp_net_ import MacAddress          as MacAddress
-from vmp_net_ import Udp                 as Udp
 from vmp_net_ import udpui               as udpui
 from vmp_net_ import UdpUI               as UdpUI
-from vmp_net_ import TcpClient           as TcpClient
-from vmp_net_ import TcpServer           as TcpServer
-from vmp_net_ import tcpserver_free_connection as tcpserver_free_connection
-from vmp_net_ import TcpListen           as TcpListen
 from vmp_net_ import tcpui               as tcpui
 from vmp_net_ import TcpUI               as TcpUI
  
