@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/09/2022
+   Date last update: 15/03/2024
  */
 
 #include "vmp.h"
@@ -33,7 +33,27 @@
     is_macaddress_raw(),macaddress_to_buf(),macaddress_from_buf()
 */
 /*!
-    Function c++ in net/socket.h:<BR>socket_timeout()
+    Const c++ in net/connection.h:<BR>CONN_NONE,CONN_UDP4,CONN_UDP6,CONN_UDPCONNECT,CONN_UDPPROXY
+                 CONN_TCPSERVER,CONN_TCPCLIENT,CONN_TCPPROXY    
+                 
+*/
+/*!
+    Const c++ in net/connection.h:<BR>conn_strtype()
+*/
+//!Python wrapper of the c++ namespace vampiria::net in vmp_net.(see c++ doc)
+/*!
+    ProxyInfo Class in net/connection.h:<BR>Constructor ProxyInfo()<BR>
+    ProxyInfo member function list:<BR>reset(),addr()
+*/
+/*!
+    Const c++ in net/socket.h:<BR>UDP_MSIZE_DEFAULT
+*/
+/*!
+    Function c++ in net/socket.h:<BR>
+             socket_datagram(),socket_stream(),socket_connect_check(),
+             socket_bind(),socket_listen(),socket_accept(),socket_addrlocal(),
+             socket_addrpeer(),socket_close(),socket_timeout(),socket_recvFrom(),
+             socket_recv(),socket_sendTo(),socket_send()
 */
 /*!
     Function c++ in net/dns.h:<BR>tcp_resolve4(),tcp_resolve6(),tcp_resolveMX()
@@ -43,7 +63,7 @@ void net_init(pylib::Module module);
 //!Python wrapper of the c++ class vampiria::net::Address in vmp_net.Address(see c++ doc)
 /*!
     Address class in net/address.h:<BR>Constructor Address() or Address(dnstype,dnsip) or Address(dnstype,dnsip,dnsport) or Address(dnstype,dnsip,dnsport,dnstout)<BR>
-    Address member function list:<BR>reset(),set(),set_ip_raw(),copy(),host(),ip(),service(),is_ipv4(),is_ipv6()
+    Address member function list:<BR>reset(),set(),set_ip_raw(),copy(),host(),ip(),service(),is_ipv4(),is_ipv6(),onlyhost()
 */
 void net_init_address(pylib::Module module);
 
@@ -60,14 +80,6 @@ void net_init_macaddress(pylib::Module module);
 */
 void net_init_netdevice(pylib::Module module);
 
-//!Python wrapper of  of the c++ class vampiria::net::Udp in vmp_net.Udp(see c++ doc)
-/*!
-    Udp class in net/udp.h:<BR>Constructor Udp()<BR>
-    Udp  member function list:<BR>reset(),socket(),block(),noblock(),set_maxpsize(),maxpsize(),get_local_address(),server(),client4(),client6(),
-                                  sendTo(),recvFrom(),close()
-*/
-void net_init_udp(pylib::Module module);
-
 //!Python wrapper of  of the c++ class vampiria::net::UdpUI in vmp_net.UdpUI(see c++ doc)
 /*!
     Wrapper Cell->ui() for udp in udpui(cell)<BR>
@@ -75,31 +87,13 @@ void net_init_udp(pylib::Module module);
 */
 /*!
     UdpUI Class in net/udp.h:<BR>Constructor UdpUI(manager)<BR>
-    UdpUI member function list:<BR>set_event(),new_server(),new_client4(),new_client6(),sendTo(),maxpsize(),localaddr()
+    UdpUI member function list:<BR>
+      set_event(),new_bind(),new_udp4(),new_udp6(),new_client(),sendTo(),
+      send(),maxpsize(),localaddr(),peeraddr(),proxyinfo(),connection_type(),
+      connection_strtype()
 */
 void net_init_udpui(pylib::Module module);
 
-
-//!Python wrapper of  of the c++ class vampiria::net::TcpClient,vampiria::net::TcpListen,vampiria::net::TcpServer in vmp_net.Tcp*(see c++ doc)
-/*!
-    TcpClient class in net/tcp.h:<BR>Constructor TcpClient()<BR>
-    TcpClient member function list:<BR>reset(),socket(),block(),noblock(),get_local_address(),get_peer_address(),sendData(),recvData(),close(),
-                                       connect(),connect_check()
-*/
-/*!
-    TcpServer class in net/tcp.h:<BR>no Constructor<BR>
-    TcpServer member function list:<BR>socket(),get_local_address(),get_peer_address(),sendData(),recvData(),close()
-    
-*/
-/*!
-    Free server connection(net/tcp.h):<BR> vmp_net.tcpserver_free_connection(server) 
-*/
-/*!
-    TcpListen class in net/tcp.h:<BR>Constructor TcpListen()<BR>
-    TcpListen member function list:<BR>reset(),socket(),block(),noblock(),get_local_address(),close(),server(),accept()
-*/
-void net_init_tcp(pylib::Module module);
-
 //!Python wrapper of  of the c++ class vampiria::net::TcpUI in vmp_net.TcpUI(see c++ doc)
 /*!
     Wrapper Cell->ui() for tcp in tcpui(cell)<BR>
@@ -107,7 +101,8 @@ void net_init_tcp(pylib::Module module);
 */
 /*!
     TcpUI Class in net/tcp.h:<BR>Constructor TcpUI(manager)<BR>
-    TcpUI member function list:<BR>set_event_client(),set_event_server(),new_client(),new_server(),send(),localaddr(),peeraddr()
+    TcpUI member function list:<BR>set_event_client(),set_event_server(),new_client(),new_server(),send(),localaddr(),peeraddr(),
+         proxyinfo(),connection_type()
 */
 void net_init_tcpui(pylib::Module module);
 
