@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 20/06/2023
+   Date last update: 12/02/2024
  */
 
 #include "vmp.h"
@@ -89,23 +89,22 @@ typedef enum cellstate {ACTIVE,CLOSEWAIT,CLOSE} CELLSTATE;
 typedef enum cellret {NOCLOSE,SUCCESS,ERROR,TIMEOUT} CELLRET;
 
 const vmp_int MAX_CELL_PRIORITY=999;/*!<Max cell priority*/
-const vmp_int BREAKLOOP_PRIORITY=1000;/*!<Special event breakloop priority(It must be the second event executed)*/
+const vmp_int BREAKLOOP_PRIORITY=1000;/*!<Special event breakloop priority*/
 
 //! Cell event reference.An event is associated with each cell
 class Cell:public vmp::utils::Container<vmp::str>
 {
     private:
        friend event::Manager;
-       event::CELLSTATE state_;         /*!< Cell state*/
-       vmp::time::Time timeout_;        /*!< Cell timeout*/
-       vmp::time::Time timewait_;       /*!< Maximum time of inactivity allowed to the Cell*/
-       vmp_index   nwait_;              /*!< Number of events executable in the state CLOSEWAIT*/
-       vmp_index   refalloc_;           /*!<References Cell allocated*/
+       event::CELLSTATE state_;   /*!< Cell state*/
+       
+       vmp_index   nwait_;        /*!< Number of events executable in the state CLOSEWAIT*/
+       vmp_index   refalloc_;     /*!<References Cell allocated*/
       
-       event::UI *ui_;                  /*!<User interface associated with event*/
-       event::Event *event_;            /*!<Event handle*/
-       event::Manager *manager_;        /*!<Associated manager*/
-       vmp_int priority_;               /*!<Priority of the event execution*/
+       event::UI *ui_;           /*!<User interface associated with event*/
+       event::Event *event_;     /*!<Event handle*/
+       event::Manager *manager_; /*!<Associated manager*/
+       vmp_int priority_;        /*!<Priority of the event execution*/
        
        //! Reset cell
        void reset();
@@ -117,14 +116,19 @@ class Cell:public vmp::utils::Container<vmp::str>
        //! A Destructor
        ~Cell();
 
-       event::EVTCB read_;              /*!<Read callback*/
-       event::EVTCB close_;             /*!<close callback*/
+       vmp::time::Time timeout_;  /*!< Cell timeout*/
+       vmp::time::Time timewait_; /*!< Maximum time of inactivity allowed to the Cell*/
        
-       event::CELLRET ret_;             /*!<Exit code*/
-       vmp::str err_;                   /*!<Error info. With Exit code ERROR*/
+       event::EVTCB read_;/*!<Read callback*/
+       event::EVTCB close_;/*!<close callback*/
        
-       vmp::str evtype_;                /*!<Used in UI for managing multiple event types(default generic)*/
-       vmp_bool writing_;               /*!<True writing associated select fd,otherwise false(default false)*/
+       event::CELLRET ret_;/*!<Exit code*/
+       vmp::str closelevel_; /*!<specify the event that caused the closure*/
+       vmp_int errcode_;   /*!<Used with close_err_spec() to specify the error code*/
+       vmp::str err_;      /*!<Error info. With Exit code ERROR*/
+       
+       vmp::str evtype_;  /*!<Used in UI for managing multiple event types(default generic)*/
+       vmp_bool writing_; /*!<True writing associated select fd,otherwise false(default false)*/
 
        //!Return a string that identifies the event(monitor)
        /*!
@@ -134,20 +138,39 @@ class Cell:public vmp::utils::Container<vmp::str>
        vmp::str identity();
        
        //!Close event with state SUCCESS(monitor)
-       void close();
+       /*!
+           @param closelevel close level value
+           @ref ret_
+       */
+       void close(vmp::str closelevel="");
 
        //!Assigns a number of events to the event to be executed before closing
        /*!
             @param n number of events executed before closing
+            @param closelevel close level value
        */
-       void close_wait(vmp_uint n);
+       void close_wait(vmp_uint n,vmp::str closelevel="");
        
        //!Close event with state ERROR(monitor)
        /*!
+           @ref ret_
+           @ref err_
            @param err error return string
        */
        void close_err(vmp::str err);
        
+       //!Close event with state ERROR(monitor) and specifies the event that generated the error and its error code.
+       /*!
+           @ref ret_
+           @ref errlevel_
+           @ref errcode_
+           @ref err_
+           @param errlevel event level
+           @param errcode error code
+           @param err error return string
+       */
+       void close_err_spec(vmp::str closelevel,vmp_int errcode,vmp::str err);
+       
        //!Alloc cell references(monitor)
        /*!
            @sa refalloc_
@@ -168,6 +191,20 @@ class Cell:public vmp::utils::Container<vmp::str>
        */
        event::CELLRET ret();
 
+       //!Return close level value(monitor)
+       /*!
+           @return close level value
+           @sa closelevel_
+       */
+       vmp::str closelevel();
+       
+       //!Return error code value(monitor)
+       /*!
+           @return error code value
+           @sa errcode_
+       */
+       vmp_int errcode();
+       
        //!Returns error string(monitor)
        /*!
            @return error string
@@ -219,11 +256,10 @@ class Cell:public vmp::utils::Container<vmp::str>
 
        //! Operator to compare tag which has more or less of the other priorities                
        /*!
-            @param c1 cell 1
-            @param c2 cell 2
-            @return true if c2 has higher priority than c1 otherwise false(hight numbers have higher priority)                
+            @param cell cell compare
+            @return true if cell has higher priority than this otherwise false(hight numbers have higher priority)                
        */                
-       vmp_bool operator()(Cell *&c1,Cell *&c2);
+       vmp_bool operator<(Cell &cell);
 };
 
 //! Event manager 
@@ -233,11 +269,10 @@ class Manager
        friend event::Cell;
        vmp::time::Timer timer_;/*!<Used to calculate the time elapsed since the manager was created*/
        vmp::time::Time timeout_;/*!<Timeout setting*/
-       vmp::time::Time now_;/*!<Time now*/
        vmp::utils::Storage<Cell> cellref_;/*!<Storage utility for cell create*/
        vmp_bool loop_;/*!<variable used internally to verify that the loop is active*/
        vmp_bool init_;/*!<Manager is init?*/
-       vmp::priority_queue<event::Cell *,vmp::vector<event::Cell *>,event::Cell > pcell_;/*!<Priority cell build queue*/ 
+       vmp::priority_queue<event::Cell *,vmp::vector<event::Cell *>,vmp::less<vmp::vector<Cell*>::value_type> > pcell_;/*!<Priority cell build queue*/ 
        event::BreakloopUI *breakui_;/*!<Breakloop user interface*/
        vmp::thread::Mutex mutex_;/*!<variable mutual exclusion manager*/
        vmp::thread::Pthread self_;/*!<Thread id self*/
@@ -267,7 +302,7 @@ class Manager
        vmp_bool forced_unlock();
 
        //! Recovery lock after a forced_unlock() call
-       /*!
+       /*!vmp::str errinfo="",vmp::str errlevel="",vmp_int errcode=0
            @param status value returned from forced_unlock() function
        */
        void recovery_lock(vmp_bool status);        
@@ -285,7 +320,7 @@ class Manager
        
        //!Update cell status.(call in read and write function)
        /*!
-            @param cell cell update
+            @param cell cell updatehttps://duckduckgo.com/
             @return true if cell is active,otherwise false
        */
        vmp_bool cell_update(event::Cell *cell);
@@ -297,25 +332,43 @@ class Manager
        */
        void cell_timewait(event::Cell *cell,vmp::time::Time timewait);
 
-       //!Internal use. Used for close event(no monitor)
+       //!Internal usage. Used for close event(no monitor)
        /*!
            @param cell cell to close
            @param retcode (see CELLRET)
-           @param errinfo error info(id retcode==ERROR)
+           @param errinfo error info
        */
        void cell_close(event::Cell *cell,event::CELLRET retcode,vmp::str errinfo="");
        
+       //!Used for close event with specific close level(no monitor)
+       /*!
+           @param cell cell to close
+           @param closelevel event event that generates the error
+           @param closelevel close level value
+           @param errinfo error info
+       */
+       void cell_close_ok_spec(event::Cell *cell,vmp::str closelevel);
+       
+       //!Used for close event with specific close level and error value(no monitor)
+       /*!
+           @param cell cell to close
+           @param closelevel close level value
+           @param errcode error code
+           @param errinfo error info
+       */
+       void cell_close_err_spec(event::Cell *cell,vmp::str closelevel,vmp_int errcode,vmp::str errinfo);
+       
        //!Assigns a number of events to the event to be executed before closing
        /*!
            @param cell cell to close wait
            @param n number of events executed before closing
        */
-       void cell_closewait(event::Cell *cell,vmp_uint n);
+       void cell_closewait(event::Cell *cell,vmp_uint n,vmp::str closelevel="");
        
        //!Returns the current time (since the creation of the manager)
        /*!
            @return the current time
-           @sa now_
+           @sa timer_
        */
        vmp::time::Time time_now();
 
