@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 15/05/2020
+ * Date last update: 11/11/2023
  */
 
 #ifndef VAMPIRIA_EVENT_EVENTTIMER_H
@@ -60,6 +60,12 @@ class EventTimer:public event::Event
         //!Deactive timer event.To reactivate it, use evt_timer_active
         void evt_timer_deactive();
 
+        //! Check to see if the timer is active
+        /*!
+            @return true timer is active otherwise false
+        */
+        vmp_bool evt_timer_isactive();
+
         //! Close Timer event
         void evt_timer_close();
 
