@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 02/07/2023
+   Date last update: 09/02/2024
  */
 
 #include "event.h"
@@ -44,7 +44,6 @@ void Manager::init()
     if(!init_)
     {
         timeout_=0.0;
-        now_=timer_.now();
         loop_=true;
         init_=true;
         breakui_->init();
@@ -116,7 +115,7 @@ vmp_bool Manager::cell_update(event::Cell *cell)
         cell->nwait_--;
     }
     if(cell->timewait_ != 0.0)
-       cell->timeout_=now_+cell->timewait_;
+       cell->timeout_=time_now()+cell->timewait_;
     return true;
 }
 
@@ -125,7 +124,7 @@ void Manager::cell_timewait(event::Cell *cell,vmp::time::Time timewait)
     if(timewait > 0.0)
     {
         cell->timewait_=timewait;
-        cell->timeout_=now_+cell->timewait_;
+        cell->timeout_=time_now()+cell->timewait_;
     }
     else
     {
@@ -137,25 +136,40 @@ void Manager::cell_timewait(event::Cell *cell,vmp::time::Time timewait)
 
 void Manager::cell_close(event::Cell *cell,event::CELLRET retcode,vmp::str errinfo)
 {
-   if(cell->state_ != event::CLOSE)
-   {
-       cell->state_=event::CLOSE;
-       cell->ret_=retcode;
-       cell->err_=errinfo;
-       cell->ui_->close_event(cell);
-       breakloop();
-   }
+    if(cell->state_ != event::CLOSE)
+    {
+        cell->ret_=retcode;
+        cell->err_=errinfo;
+        cell->state_=event::CLOSE;
+        cell->ui_->close_event(cell);
+        breakloop();
+    }
 }
 
-void Manager::cell_closewait(event::Cell *cell,vmp_uint n)
+void Manager::cell_close_ok_spec(event::Cell *cell,vmp::str closelevel)
+{
+    cell->closelevel_=closelevel;
+    cell_close(cell,event::SUCCESS);
+        
+}
+
+void Manager::cell_close_err_spec(event::Cell *cell,vmp::str closelevel,vmp_int errcode,vmp::str errinfo)
+{
+    cell->closelevel_=closelevel;
+    cell->errcode_=errcode;
+    cell_close(cell,event::ERROR,errinfo);
+}
+
+void Manager::cell_closewait(event::Cell *cell,vmp_uint n,vmp::str closelevel)
 {
    if(cell->state_ == event::ACTIVE)
    {
        if(n == 0)
-           cell_close(cell,event::SUCCESS);
+           cell_close_ok_spec(cell,closelevel);
        else
        {
            cell->state_=event::CLOSEWAIT;
+           cell->closelevel_=closelevel;
            cell->nwait_=n;
        }
    }
@@ -163,7 +177,7 @@ void Manager::cell_closewait(event::Cell *cell,vmp_uint n)
 
 vmp::time::Time Manager::time_now()
 {
-    return now_;
+    return timer_.now();
 }
 
 void Manager::set_timeout(vmp::time::Time timeout)
@@ -182,12 +196,16 @@ void Manager::cell_alloc(event::Cell *cell)
 
 void Manager::cell_release(event::Cell *cell)
 {
-    cell->refalloc_--;
-    if(cell->refalloc_==0)
+    if(cell->refalloc_ > 1)
+        cell->refalloc_--;
+    else if (cell->refalloc_ == 1)
     {
+        cell->refalloc_=0;
         cell->ui_->free_ref(cell);
         cellref_.free(cell);
     }
+    else
+        vmp::warning_s("event::Manager::cell_release() cell already released");
 }
 
 void Manager::stop()
@@ -204,7 +222,7 @@ void Manager::loop()
     event::Cell *cell;
     vmp::vector<event::Cell *> vread;
     vmp::vector<event::Cell *> vclose;
-    vmp::time::Time stimeout;
+    vmp::time::Time now,stimeout;
     vmp_size s;
     while(1)
     {
@@ -245,15 +263,24 @@ void Manager::loop()
             cell->release();
         }
         lock();
-        if(s > 0)
-            breakui_->active();
         for(vmp_index i=0;i<vread.size();i++)
             set_timeout(vread[i]->timeout_);
+        now=timer_.now();
         if(timeout_ > 0.0)
-           stimeout=timeout_-now_;
+        {
+           if(timeout_ <= now)
+             stimeout=-1.0;
+           else
+             stimeout=timeout_-now;
+        }
         else
            stimeout=0.0;
         timeout_=0.0;
+        if((s > 0) || stimeout == -1.0)
+        {
+            stimeout=0.0;
+            breakui_->active();
+        }
         unlock();
         if(vread.size() > 0)
         {    
@@ -263,32 +290,31 @@ void Manager::loop()
         else
             break;
         lock();
-        now_=timer_.now();
+        now=timer_.now();
         unlock();
         for(vmp_index i=0;i<vread.size();i++)
         {    
             cell=vread[i];
             lock();
             vmp_bool rbool=cell->event_->active_;
-            if((cell->timeout_) != 0.0 && (cell->timeout_<=now_))
-            {    
-                cell_close(cell,event::TIMEOUT);
-                rbool=false;
-            }
-            pcell_.push(cell);
             unlock();
             if(rbool)
             {
-               try
-               {
+                try
+                {
                    cell->read_(cell);
-               }
-               catch(vmp::exception &x)
-               {
+                }
+                catch(vmp::exception &x)
+                {
                    forced_unlock();
                    cell->close_err(x.what());
-               }
+                }
             }
+            lock();
+            if((cell->timeout_) != 0.0 && (cell->timeout_<=now))
+                cell_close(cell,event::TIMEOUT);
+            pcell_.push(cell);
+            unlock();
         }
     }
     init_=false;
