@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 03/05/2020
+   Date last update: 18/12/2023
  */
 
 #include "event.h"
@@ -40,11 +40,13 @@ BreakloopUI::BreakloopUI(event::Manager *manager):event::UI(manager)
       
 BreakloopUI::~BreakloopUI()
 {
+    manager_->cell_release(cell_);
 }
 
 void BreakloopUI::init()
 {
     cell_=evtpipe_.evt_pipe_new(this, breakloop_ev,0);
+    manager_->cell_alloc(cell_);
 }
 
 void BreakloopUI::active()
