@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
- * Date last update: 10/08/2021
+ * Date last update: 14/01/2023
  */
 
 #ifndef VAMPIRIA_EVENT_THREADUI_H
@@ -43,7 +43,8 @@ class ThreadUI:public event::UI
 {
     private:
         vmp::utils::Storage<ThreadRef> tref_;/*!<Storage event*/
-        event::EVTCB revent_;/*!<Callback performed by the thread*/
+        event::EVTCB active_;/*!<Callback call when activating the main event*/
+        event::EVTCB run_;   /*!<Callback performed by the thread*/
         event::EVTCB cancel_;/*!<Callback performed by the cancel exec*/
         event::EVTCB cevent_;/*!<Callback close event*/ 
     public:
@@ -67,11 +68,12 @@ class ThreadUI:public event::UI
 
         //!Set Thread event
         /*!
-            @param revent Callback performed by the thread
+            @param active callback performed when activating the main event
+            @param run Callback performed by the thread
             @param cancel Callback performed by the cancel exec(default pthread_cancel)
             @param cevent close event callback 
         */
-        void set_event(event::EVTCB run,event::EVTCB cancel,event::EVTCB cevent);
+        void set_event(event::EVTCB active,event::EVTCB run,event::EVTCB cancel,event::EVTCB cevent);
         
         //! Create new thread event
         /*!
@@ -80,6 +82,12 @@ class ThreadUI:public event::UI
         */
         event::Cell *new_thread(vmp::str id);
 
+        //! Active the main event
+        /*!
+            @param cell cell associated
+        */
+        void active_main(event::Cell *cell);
+
         //! Start thread event
         /*!
             @param cell cell associated
