@@ -16,10 +16,11 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/10/2023
+   Date last update: 20/02/2024
  */
 
 #include "vmp.h"
+#include "event.h"
 #include "net.h"
 #include "packet.h"
 #include <json-c/json.h>
@@ -559,5 +560,5 @@ class JsonObj
 #include "json/jtable.h"
 #include "json/japi.h"
 #include "json/jrp.h"
-
+#include "json/status.h"
 
