@@ -244,6 +244,28 @@ vmp_real JData::get_real_range(vmp::str label,vmp_real min,vmp_real max)
     return 0.0;    
 }
 
+void JData::set_bool(vmp::str label,vmp_bool value)
+{
+    json::JsonObj jbody,obj;
+    get_jbody("set_bool",&jbody);
+    jbody.add_object_bool(label,value,&obj);
+}
+
+vmp_bool JData::get_bool(vmp::str label)
+{
+    json::JsonObj jbody;
+    get_jbody("get_bool",&jbody);
+    try
+    {
+        return jbody.get_object_bool(label);
+    }
+    catch(vmp::exception &x)
+    {
+        json::primitive_error(label);   
+    }
+    return false;
+}
+
 void JData::new_list(vmp::str label,json::JList *list,vmp::str jtype)
 {
     vmp::except_check_pointer((void *) list,"json::JData::new_list() null input pointer list");
@@ -386,30 +408,65 @@ void JData::get_vars(vmp::str label,vmp::Table<vmp::str,vmp::str> *vars)
 
 void JData::set_custom(vmp::str label,json::JsonObj *obj)
 {
-    vmp::except_check_pointer((void *) obj,"json::JData::set_custom() null pointer input obj");
-    if(!obj->isobject())
-        vmp::except("json::JData::set_custom() input obj bad object");
+    json::JsonObj tmp;
     json::JsonObj jbody;
     get_jbody("set_custom",&jbody);
-    jbody.add_object_ex(label,obj);
+    if(obj != 0)
+    {
+        if(!obj->isobject())
+            vmp::except("json::JData::set_custom() input obj bad object");
+        jbody.add_object_ex(label,obj);
+    }
+    else
+        jbody.add_object_obj(label,&tmp);
 }
 
 void JData::get_custom(vmp::str label,json::JsonObj *obj)
 {
     vmp::except_check_pointer((void *) obj,"json::JData::get_custom() null pointer input obj");
-    json::JsonObj jbody,custom,tmp;
+    json::JsonObj jbody;
     get_jbody("get_custom",&jbody);
     try
     {
-        if(!obj->isobject())
-            vmp::except("");
-        jbody.get_object(label,&custom);
-        vmp::vector<vmp::str> keys=custom.keys();
-        for(vmp_index i=0;i<keys.size();i++)
-        {
-            custom.get_object(keys[i],&tmp);
-            obj->add_object_ex(keys[i],&tmp);
-        }
+        jbody.get_object(label,obj);
+    }
+    catch(vmp::exception &x)
+    {
+        json::primitive_error(label);   
+    }
+}
+
+void JData::set_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
+{
+    vmp::except_check_pointer((void *) jdata,"json::JData::set_subtype() null pointer input jdata");
+    json::JData j;
+    json::JsonObj jbody;
+    get_jbody("set_subtype",&jbody);
+    try
+    {
+        j.set(jdata);
+        if((jtype != "") && (j.jtype() != jtype))
+            json::set_primitive_error(label);
+        jbody.add_object_ex(label,jdata);
+    }
+    catch(vmp::exception &x)
+    {
+        json::set_primitive_error(label);   
+    }
+}
+
+void JData::get_subtype(vmp::str label,json::JsonObj *jdata,vmp::str jtype)
+{
+    vmp::except_check_pointer((void *) jdata,"json::JData::get_subtype() null pointer input jdata");
+    json::JData j;
+    json::JsonObj jbody,tmp;
+    get_jbody("get_subtype",&jbody);
+    try
+    {
+        jbody.get_object(label,jdata);
+        j.set(jdata);
+        if((jtype != "") && (j.jtype() != jtype))
+            json::primitive_error(label);
     }
     catch(vmp::exception &x)
     {
@@ -461,10 +518,10 @@ void JData::get_netaddress(vmp::str label,net::Address *address)
     get_jbody("get_netaddress",&jbody);
     try
     {
-         jbody.get_object(label,&obj);
-         vmp::str host=obj.get_object_str("host");
-         vmp::str service=obj.get_object_str("service");
-         address->set(host,service);
+        jbody.get_object(label,&obj);
+        vmp::str host=obj.get_object_str("host");
+        vmp::str service=obj.get_object_str("service");
+        address->set(host,service);
     }
     catch(vmp::exception &x)
     {
