@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 06/04/2022
+   Date last update: 14/03/2024
 */
 
 #ifndef VAMPIRIA_JSON_JTABLE_H
@@ -86,9 +86,9 @@ class JTable
         //!Delete the JData associated with the key from the table
         /*!
             @param Key associated with the jdata
-            @return void or except in case of failure
+            @return true if the value is cancelled,false if value not found  or except in case of failure
         */
-        void cancel(vmp::str jkey);
+        vmp_bool cancel(vmp::str jkey);
  
         //!Search the JData associated with the key from the table
         /*!
