@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/02/2020
+   Date last update: 01/03/2024
  */
 
 #include "vmp.h"
@@ -35,15 +35,12 @@
 namespace vampiria { namespace net {
 
 typedef void (*EVTCBRECVFROM)(event::Cell *cell,vmp::Buf *buf,net::Address *peer);/*<!Event recvfrom callback(see framework event)*/
-typedef void (*EVTCBRECV)(event::Cell *cell,vmp::Buf *buf);/*<!Event recv callback (see framework event)*/
+
 typedef void (*EVTCBACCEPT)(event::Cell *listen,event::Cell *server);/*<!Event accept callback (see framework event)*/
 
 //! Empty EVTCBRECVFROM callback
 void empty_recvfrom_ev(event::Cell *cell,vmp::Buf *buf,net::Address *peer);
 
-//! Empty EVTCBRECV callback
-void empty_recv_ev(event::Cell *cell,vmp::Buf *buf);
-
 //! Empty EVTCBACCEPT callback
 void empty_accept_ev(event::Cell *listen,event::Cell *server);
 
@@ -52,6 +49,7 @@ void empty_accept_ev(event::Cell *listen,event::Cell *server);
 #endif
 
 #include "net/netdevice.h"
+#include "net/connection.h"
 #include "net/udp.h"
 #include "net/tcp.h"
 #include "net/dns.h"
