@@ -16,10 +16,11 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 01/12/2019
+   Date last update: 26/03/2024
  */
 
 #include <string>
+#include <cstring>
 #include <vector>
 #include <utility>
 #include <limits>
@@ -31,6 +32,7 @@
 #include <set>
 #include <queue>
 #include <memory>
+#include <algorithm> 
 
 #include <string.h>
 #include <strings.h>
@@ -123,6 +125,22 @@ template < class T,                        //! set::key_type/value_type
            > 
 using set=std::set<T,Compare,Alloc>;
 
+//! see doc c++ std::less
+template<class T>
+using less=std::less<T>;
+
+//! see doc c++ std::less_equal
+template<class T>
+using less_equal=std::less_equal<T>;
+
+//! see doc c++ std::greater
+template<class T>
+using greater=std::greater<T>;
+
+//! see doc c++ std::greater_equal
+template<class T>
+using greater_equal=std::greater_equal<T>;
+
 //!see doc c++ std::priority queue
 template <class T, class Container = vmp::vector<T>,class Compare = std::less<typename Container::value_type> > 
 using priority_queue=std::priority_queue<T,Container,Compare>;
@@ -131,6 +149,35 @@ using priority_queue=std::priority_queue<T,Container,Compare>;
 template <class T, class Container = std::deque<T> >
 using queue=std::queue<T,Container>;
 
+//!Takes an input array and returns an ordered array
+/*
+    @param v input array
+    @param reverse false ascending order,true descending
+    @param duplicate if false remove duplicate value
+    @return ordered carrier
+*/
+template <class T>
+vmp::vector<T> sort(vmp::vector<T> v,vmp_bool reverse=false,vmp_bool duplicate=true)
+{
+    vmp::vector<T> ret=v;
+    if(reverse)
+        std::sort(ret.begin(),ret.end(),std::greater<T>());
+    else
+        std::sort(ret.begin(),ret.end());
+    if(!duplicate)
+        ret.erase(std::unique(ret.begin(),ret.end()),ret.end());
+    return ret;
+}
+
+template <class T>
+vmp_bool invector(T value,vmp::vector<T> values)
+{
+    for(vmp_index i=0;i<values.size();i++)
+        if(value == values[i])
+            return true;
+    return false;
+}
+
 const vmp_int INTMIN=std::numeric_limits<vmp_int>::min(); /*!< Minimum limit integer*/
 const vmp_int INTMAX=std::numeric_limits<vmp_int>::max(); /*!< Maximum limit integer*/
 const vmp_int16 INT16MIN=std::numeric_limits<vmp_int16>::min(); /*!< Minimum limit short integer*/
