@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 25/03/2023
+   Date last update: 04/04/2024
  */
 
 #ifndef VAMPIRIA_VMP_ENV_H
@@ -62,17 +62,24 @@ vmp::str version();
 */
 vmp::str vampiria_path(vmp::str subpath="");
 
+//!Returns the absolute path of a vampiria framework 
+/*!
+    @param subpath path inside in framework
+    @return the string of framework path.If an empty string is subpath it returns the framework path
+*/
+vmp::str vampiria_frm(vmp::str subpath="");
+
 //!Returns the absolute path of a vampiria executable file
 /*!
     @param name program name
-    @return the absolute path executable if it exists,otherwise throw exception
+    @return the absolute path executable if it exists or except in case of failure
 */
 vmp::str vampiria_bin(vmp::str name);
 
 //!Returns the absolute path of a vampire library external to the framework
 /*!
     @param name lib name library name without the extension .so
-    @return the absolute path library if it exists,otherwise throw exception
+    @return the absolute path library if it exists or except in case of failure
 */
 vmp::str vampiria_lib(vmp::str name);
 
@@ -213,6 +220,18 @@ vmp_bool python_files_check(vmp::str path);
 */
 vmp::str xml_hdr();
 
+//! Given an input with the following characteristics:
+//! If it starts for ${}/ the directories considered are the root of the framework;
+//! If it starts for ${subsystem}/ the directories considered are subsystems of the framework;
+//! If it starts with  $ it reads $;
+//! If it starts \value to be read value.(example \\ = \ \$=\)
+//! The subsystem are:'bin' binary executable,'lib' library path,'cache' cache directory,'home' home path,'software' software path,'modules' modules path,'pkg' package path,'vpkg' python pkg subdirectory,'frm' framework path
+/*!
+    @param path path string
+    @return formatted string path or except in case of failure
+*/
+vmp::str format_path(vmp::str path);
+
 }}}
 
 #endif
