@@ -241,6 +241,8 @@ vmp::str input()
         {
             vmp::str ret=streamcin_;
             streamcin_="";
+            if(ret == "")
+              return "\n";
             return ret;
         }
         streamcin_+=c;
