@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/01/2020
+   Date last update: 10/03/2024
  */
 
 #include <stdlib.h>
@@ -92,7 +92,7 @@ void usleep_wrap(vmp_uint useconds);
 
 //! Fork wrapper; Create child process;
 /*!
-    @return pid=0 in child process;pid=child process;(except error)
+    @return pid=0 in child process;pid=child process; or except in case of failure
 */
 vmp::Pid fork_wrap();
 
@@ -118,7 +118,7 @@ vmp::Uid geteuid_wrap();
 /*!
     @param oldfd old file descriptor
     @param newfd new file descriptor in old
-    @return except error
+    @return void or except in case of failure
 */
 void dup2_wrap(vmp_int oldfd,vmp_int newfd);
 
@@ -140,7 +140,7 @@ vmp_int waitpid_wrap(vmp::Pid *pid);
 /*!
     @param piper pipe read output
     @param pipew pipe write output
-    @return void (except error)
+    @return void or except in case of failure
 */
 void pipe_wrap(vmp_int *piper,vmp_int *pipew);
 
@@ -148,7 +148,7 @@ void pipe_wrap(vmp_int *piper,vmp_int *pipew);
 /*!
     @param master the pty master returned
     @param slave the pty slave returned
-    @return void (except error)
+    @return void or except in case of failure
 */
 void pty_wrap(vmp_int *master,vmp_int *slave);
 
@@ -174,7 +174,7 @@ void fd_fsync(vmp_int fd);
 /*!
     @param fd filedescriptor from read
     @param buf read buf
-    @return Number of bytes read or 0 if fd close or -1 if errno==EAGAIN(no blocking no data) or errno=EINTR(signal interrupt)(except error)   
+    @return Number of bytes read or 0 if fd close or -1 if errno==EAGAIN(no blocking no data) or errno=EINTR(signal interrupt)or except in case of failure  
 */
 vmp_int fd_read_buf(vmp_int fd,vmp::Buf *buf);
 
@@ -183,7 +183,7 @@ vmp_int fd_read_buf(vmp_int fd,vmp::Buf *buf);
      @param fd filedescriptor from read
      @param bytes output reading(memory already allocated)
      @param count maximum number of bytes read
-     @return Number of bytes read or 0 if fd close or -1 if errno==EAGAIN(no blocking no data) or errno=EINTR(signal interrupt)(except error)   
+     @return Number of bytes read or 0 if fd close or -1 if errno==EAGAIN(no blocking no data) or errno=EINTR(signal interrupt)or except in case of failure   
 */
 vmp_int fd_read_bytes(vmp_int fd,vmp_byte *bytes,vmp_size count);
 
@@ -191,7 +191,7 @@ vmp_int fd_read_bytes(vmp_int fd,vmp_byte *bytes,vmp_size count);
 /*!
     @param fd filedescriptor from read
     @param ret read data
-    @return Number of bytes read or 0 if fd close or -1 if errno==EAGAIN(no blocking no data) or errno=EINTR(signal interrupt)(except error)
+    @return Number of bytes read or 0 if fd close or -1 if errno==EAGAIN(no blocking no data) or errno=EINTR(signal interrupt)or except in case of failure
 */
 vmp_int fd_read(vmp_int fd,vmp::str *ret);
 
@@ -199,7 +199,7 @@ vmp_int fd_read(vmp_int fd,vmp::str *ret);
 /*!
     @param fd filedescriptor to write
     @param buf buf to write
-    @return Number of bytes write(except error)
+    @return Number of bytes write or except in case of failure
 */
 vmp_int fd_write_buf(vmp_int fd,vmp::Buf *buf);
 
@@ -208,7 +208,7 @@ vmp_int fd_write_buf(vmp_int fd,vmp::Buf *buf);
     @param fd filedescriptor to write
     @param bytes bytes to write
     @param count bytes number to write
-    @return Number of bytes write(except error)
+    @return Number of bytes write or except in case of failure
 */
 vmp_int fd_write_bytes(vmp_int fd,vmp_byte *bytes,vmp_size count);
 
@@ -216,7 +216,7 @@ vmp_int fd_write_bytes(vmp_int fd,vmp_byte *bytes,vmp_size count);
 /*!
     @param fd filedescriptor to write
     @param data data to write
-    @return Number of bytes write(except error)
+    @return Number of bytes write or except in case of failure
 */
 vmp_int fd_write(vmp_int fd,vmp::str data);
 
@@ -229,7 +229,7 @@ void fd_close(vmp_int *fd);
 //! Exec a command and return after the command has been completed
 /*!
     @param cmd input command
-    @return (except error)
+    @return void or except in case of failure
 */
 void system_wrap(vmp::str cmd);
 
@@ -238,7 +238,7 @@ void system_wrap(vmp::str cmd);
     @param filename binary executable
     @param argv an array of argument strings passed to the new program
     @param envp an array of strings, conventionally of the form key=value, which are  passed an environment to the new program
-    @return void (except error)
+    @return void or except in case of failure
 */
 void execve_wrap(vmp::str filename,vmp_char *const argv[],vmp_char *const envp[]);
 
@@ -260,7 +260,7 @@ vmp_int getopt_wrap(vmp_int argc, vmp_char *const argv[],vmp::str optstring);
     @param ifname interface name
     @param request request code
     @param ifr pointer to interface structure(see man linux)
-    @return void(except error)
+    @return void or except in case of failure
 */
 void ioctl_wrap_ifreq(vmp_int sock,vmp::str ifname,vmp_uint request,struct ifreq *ifr);
 
@@ -314,7 +314,7 @@ typedef mode_t Mode;
 //!Delete a file system name
 /*!
     @param path path name
-    @return void (except error)
+    @return void or except in case of failure
 */
 void unlink_wrap(vmp::str path);
 
@@ -333,25 +333,32 @@ vmp::str format_dirpath(vmp::str dirpath);
 */
 vmp::str union_path(vmp::str dirpath,vmp::str subpath="");
 
-//!Attempts to create a directory named pathname
+//!changes the permissions to a file
+/*!
+    @param path file file
+    @param mode specifies the mode permissions(0ugo permission filesystem) 
+*/
+void chmod_wrap(vmp::str path,vmp::fs::Mode mode);
+
+//! Create a directory named pathname
 /*!
     @param dirpath pathname
-    @param mode specifies the mode for the new directory(0755 permission filesystem) 
-    @return void (except error)
+    @param mode specifies the mode for the new directory(0ugo permission filesystem) 
+    @return void or except in case of failure
 */
 void mkdir_wrap(vmp::str dirpath,vmp::fs::Mode mode);
 
 //!Deletes a directory and its contents(recursive mode)
 /*!
     @param dirpath directory path
-    @return void (except error)
+    @return void or except in case of failure
 */
 void rmdir_wrap(vmp::str dirpath);
 
 //!Changes the current working directory
 /*!
     @param path dierctory to working
-    @return void (except error)
+    @return void or except in case of failure
 */ 
 void chdir_wrap(vmp::str path);
 
@@ -385,14 +392,14 @@ vmp_bool isxdir(vmp::str dirpath);
 
 //!Return string containing an absolute pathname that is the current working directory of the calling  process.
 /*!
-    @return current working directory(except error)
+    @return current working directory or except in case of failure
 */
 vmp::str getcwd_wrap();
 
 //!Listen directory
 /*!
     @param dirpath directory to listen
-    @return listen directory(except error)
+    @return listen directory or except in case of failure
 */
 vmp::vector<vmp::str> listendir(vmp::str dirpath);
 
@@ -503,16 +510,16 @@ class Instance
         }
 };
 
-//!Reset the vector and free up data storage space. The DATA type must be a pointer and allocated with vmp::malloc_wrap
+//!Reset the vector and free up data storage space. The DATA type must be a pointer and allocated with vmp::malloc_wrap()
 /*!
-    @param vect input vector
+    @param vect pointer input vector
 */
 template<class DATA>
-void vector_free_alldata(vmp::vector<DATA> vect)
+void vector_free_alldata(vmp::vector<DATA> *vect)
 {
-    for(vmp_index i=0;i<vect.size();i++)
-        vmp::free_wrap((void **)&vect[i]);
-    vect.clear();    
+    for(vmp_index i=0;i<vect->size();i++)
+        vmp::free_wrap((void **)vect[i]);
+    vect->clear();    
 }
 
 //!Reset the vector and delete up data storage space. The DATA type must be a pointer and allocated with new
@@ -520,11 +527,11 @@ void vector_free_alldata(vmp::vector<DATA> vect)
     @param vect input vector
 */
 template<class DATA>
-void vector_delete_alldata(vmp::vector<DATA> vect)
+void vector_delete_alldata(vmp::vector<DATA> *vect)
 {
-    for(vmp_index i=0;i<vect.size();i++)
-        delete vect[i];
-    vect.clear();    
+    for(vmp_index i=0;i<vect->size();i++)
+        delete (*vect)[i];
+    vect->clear();
 }
 
 }}
