@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 18/12/2019
+   Date last update: 10/03/2024
  */
 
 #include <map>
@@ -168,30 +168,30 @@ class Table
         } 
 };
 
-//!Reset the table and free up data storage space. The DATA type must be a pointer and allocated with vmp::malloc_wrap
+//!Reset the table and free up data storage space. The DATA type must be a pointer and allocated with vmp::malloc_wrap()
 /*!
-    @param table input table
+    @param table pointer input table
 */
 template<class KEY,class DATA>
-void table_free_alldata(vmp::Table<KEY,DATA> table)
+void table_free_alldata(vmp::Table<KEY,DATA> *table)
 {
-    vmp::vector<DATA> data=table.all_data();
+    vmp::vector<DATA> data=table->all_data();
     for(vmp_index i=0;i<data.size();i++)
         vmp::free_wrap((void **)&data[i]);
-    table.clear();    
+    table->clear();    
 }
 
 //!Reset the table and delete up data storage space. The DATA type must be a pointer and allocated with new
 /*!
-    @param table input table
+    @param table pointer input table
 */
 template<class KEY,class DATA>
-void table_delete_alldata(vmp::Table<KEY,DATA> table)
+void table_delete_alldata(vmp::Table<KEY,DATA> *table)
 {
-    vmp::vector<DATA> data=table.all_data();
+    vmp::vector<DATA> data=table->all_data();
     for(vmp_index i=0;i<data.size();i++)
         delete data[i];
-    table.clear();    
+    table->clear();
 }
 
 //! multi table type
@@ -297,31 +297,32 @@ class MTable
          }    
 };
 
-//!Reset the multi table and delete up data storage space. The DATA type must be a pointer allocated with vmp::malloc_wrap
+//!Reset the multi table and delete up data storage space. The DATA type must be a pointer allocated with vmp::malloc_wrap()
 /*!
-    @param mtable input multi table
+    @param mtable pointer input multi table
 */
 template<class KEY,class DATA>
-void mtable_free_alldata(vmp::MTable<KEY,DATA> mtable)
+void mtable_free_alldata(vmp::MTable<KEY,DATA> *mtable)
 {
-    vmp::vector<DATA> data=mtable.all_data();
+    vmp::vector<DATA> data=mtable->all_data();
     for(vmp_index i=0;i<data.size();i++)
         vmp::free_wrap((void **)&data[i]);
-    mtable.clear();    
+    mtable->clear();    
 }
 
 //!Reset the multi table and delete up data storage space. The DATA type must be a pointer allocated with new
 /*!
-    @param mtable input multi table
+    @param mtable pointer input multi table
 */
 template<class KEY,class DATA>
-void mtable_delete_alldata(vmp::MTable<KEY,DATA> mtable)
+void mtable_delete_alldata(vmp::MTable<KEY,DATA> *mtable)
 {
-    vmp::vector<DATA> data=mtable.all_data();
+    vmp::vector<DATA> data=mtable->all_data();
     for(vmp_index i=0;i<data.size();i++)
         delete data[i];
-    mtable.clear();    
+    mtable->clear();    
 }
+
 }}
 
 #endif
