@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 14/10/2023
+   Date last update: 26/03/2024
  */
 
 #include "vmp.h"
@@ -43,6 +43,32 @@ vmp_size str_cwrite(vmp::str *pstr,const vmp_char *fmt,...)
     return (*pstr).size();
 }
 
+vmp_char char_tolower(vmp_char c)
+{
+     return std::tolower(c);
+}
+
+vmp_char char_toupper(vmp_char c)
+{
+     return std::toupper(c);
+}
+
+vmp::str str_tolower(vmp::str str)
+{
+    vmp::str ret="";
+    for(vmp_index i=0;i<str.size();i++)
+        ret+=char_tolower(str[i]);
+    return ret;
+}
+
+vmp::str str_toupper(vmp::str str)
+{
+    vmp::str ret="";
+    for(vmp_index i=0;i<str.size();i++)
+        ret+=char_toupper(str[i]);
+    return ret;   
+}
+
 vmp::vector<vmp::str> str_split(vmp::str str,vmp::str delimiter)
 {
     vmp::vector<vmp::str> ret;
@@ -94,23 +120,12 @@ vmp_bool byte_istype(vmp_byte byte,vmp::str type)
     return vmp::istype_wrap(byte,type);
 }
 
-vmp_bool byte_isdigit(vmp_byte byte)
+vmp_uint byte_nbit(vmp_byte byte,vmp_uint n)
 {
-    vmp::warning("function vmp::unicode::byte_isdigit(vmp_byte byte) is DEPRECATED(use vmp::unicode::byte_istype(vmp_byte byte,\"digit\")");
-    if(byte >= '0' && byte <= '9')
-        return true;    
-    return false;
+    return (byte >> n) & 0x01;
 }
 
-vmp_bool byte_isxdigit(vmp_byte byte)
-{
-    vmp::warning("function vmp::unicode::byte_isxdigit(vmp_byte byte) is DEPRECATED(use vmp::unicode::byte_istype(vmp_byte byte,\"xdigit\")");
-    if(((byte >= '0') && (byte <= '9')) || ((byte >= 'a') && (byte <= 'f')) || ((byte >= 'A') && (byte <= 'F')))
-        return true;
-    return false;  
-}
-
-vmp_bool str_istype(vmp::str str,vmp::str type)
+vmp_bool str_istype_impl(vmp::str str,vmp::str type)
 {
     for(vmp_index i=0;i<str.size();i++)
         if(!vmp::unicode::byte_istype(str[i],type))
@@ -118,48 +133,22 @@ vmp_bool str_istype(vmp::str str,vmp::str type)
     return true;
 }
 
-vmp_bool str_isdigit(vmp::str str)
+vmp_bool str_istype(vmp::str str,vmp::str type)
 {
-    vmp::warning("function vmp::unicode::str_isdigit(vmp_byte byte) is DEPRECATED(use vmp::unicode::str_istype(vmp_byte byte,\"digit\")");
-    vmp_index ivalue=0;
-    if(str.size() == 0)
+    if(type == "real")
+    {
+        vmp::vector<vmp::str> numbers=vmp::unicode::str_split(str,".");
+        if(numbers.size() == 1)
+            return vmp::unicode::str_istype_impl(numbers[0],"digit");
+        else if (numbers.size() == 2)
+        {
+            if(vmp::unicode::str_istype_impl(numbers[0],"digit"))
+                if(!((numbers[1].size() == 0) || (numbers[1][0] == '-')))
+                    return vmp::unicode::str_istype_impl(numbers[1],"digit");
+        }  
         return false;
-    if(str[0] == '-')
-    {
-        if(str.size() == 1)
-            return false;
-        else
-            ivalue=1;
-    }    
-    for(vmp_index i=ivalue;i<str.size();i++)
-        if(!vmp::unicode::byte_isdigit((vmp_byte)str[i]))
-            return false;
-    return true;
-}
-
-vmp_bool str_isxdigit(vmp::str str)
-{
-    vmp::warning("function vmp::unicode::str_isxdigit(vmp_byte byte) is DEPRECATED(use vmp::unicode::str_istype(vmp_byte byte,\"xdigit\")");
-    if(str.size() == 0)
-        return false;    
-    for(vmp_index i=0;i<str.size();i++)
-        if(!vmp::unicode::byte_isxdigit((vmp_byte)str[i]))
-            return false;    
-    return true;
-}
-
-vmp_bool str_isreal(vmp::str str)
-{
-    vmp::vector<vmp::str> numbers=vmp::unicode::str_split(str,".");
-    if(numbers.size() == 1)
-        return vmp::unicode::str_istype(numbers[0],"digit");
-    else if (numbers.size() == 2)
-    {
-        if(vmp::unicode::str_istype(numbers[0],"digit"))
-            if(!((numbers[1].size() == 0) || (numbers[1][0] == '-')))
-                return vmp::unicode::str_istype(numbers[1],"digit");
-    }  
-    return false;
+    }
+    return vmp::unicode::str_istype_impl(str,type);
 }
 
 vmp_int str_todigit(vmp::str istr)
@@ -182,7 +171,7 @@ vmp_int str_todigit_range(vmp::str istr,vmp_int min,vmp_int max)
 vmp_real str_toreal(vmp::str dstr)
 {
     vmp_real ret;
-    if(!vmp::unicode::str_isreal(dstr))
+    if(!vmp::unicode::str_istype(dstr,"real"))
         vmp::except("Invalid Conversion from string to int because '%s' not real",dstr.c_str());   
     ret=vmp::atof_wrap(dstr.c_str());
     return ret;   
@@ -496,10 +485,7 @@ vmp_bool str_regex_matching(vmp::str str,vmp::str str_regex)
 
 vmp_bool str_invector(vmp::str value,vmp::vector<vmp::str> values)
 {
-    for(vmp_index i=0;i<values.size();i++)
-        if(value == values[i])
-            return true;
-    return false;
+    return vmp::invector<vmp::str>(value,values);
 }
 
 vmp::vector<vmp::str> shlex_split(vmp::str args)
@@ -595,6 +581,62 @@ vmp::str shlex_join(vmp::vector<vmp::str> vargs)
     return ret;
 }
 
+vmp::vector<vmp_index> str_toindex_list(vmp::str istr,vmp_index minvalue,vmp_index maxvalue)
+{
+    vmp::vector<vmp_index> ret;
+    if(minvalue > maxvalue)
+        vmp::except("minvalue %d not less maxvalue %d in input",minvalue,maxvalue);
+    vmp::vector<vmp::str> split=vmp::unicode::str_split(istr,","),split2;
+    vmp::str value;
+    vmp_index min,max;
+    for(vmp_index i=0;i<split.size();i++)
+    {
+        value=vmp::unicode::str_trim(split[i]);
+        try
+        {
+            if(value == "*")
+            {
+                min=minvalue;
+                max=maxvalue;
+            }
+            else if(vmp::unicode::str_regex_matching(value,"[0-9]+"))
+            {
+                min=(vmp_index)vmp::unicode::str_todigit_range(value,minvalue,maxvalue);
+                max=min;
+            }
+            else if(vmp::unicode::str_regex_matching(value,"[0-9]+\\-[0-9]+"))
+            {
+                split2=vmp::unicode::str_split(value,"-");
+                min=(vmp_index)vmp::unicode::str_todigit_range(split2[0],minvalue,maxvalue);
+                max=(vmp_index)vmp::unicode::str_todigit_range(split2[1],minvalue,maxvalue);
+            }
+            else if(vmp::unicode::str_regex_matching(value,"[0-9]+\\-"))
+            {
+                value=vmp::unicode::str_sub(value,0,value.size()-1);
+                min=(vmp_index)vmp::unicode::str_todigit_range(value,minvalue,maxvalue);
+                max=maxvalue;
+            }
+            else if(vmp::unicode::str_regex_matching(value,"\\-[0-9]+"))
+            {
+                value=vmp::unicode::str_sub(value,1,value.size()-1);
+                min=minvalue;
+                max=(vmp_index)vmp::unicode::str_todigit_range(value,minvalue,maxvalue);
+            }
+            else
+                vmp::except("");
+            if((min < minvalue) || (max > maxvalue))
+                vmp::except("interval range (%u-%u)",minvalue,maxvalue);
+            for(vmp_index j=min;j<=max;j++)
+                ret.push_back(j);
+        }
+        catch(vmp::exception &x)
+        {
+            vmp::except("Syntax error '%s' (%s)",value.c_str(),x.what());
+        }
+    }
+    return vmp::sort<vmp_index>(ret,false,false);
+}
+
 Strtok::Strtok()
 {
     reset();
