@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 14/10/2023
+   Date last update: 27/03/2024
  */
 
 #include <regex>
@@ -45,6 +45,34 @@ vmp_size str_write(vmp::str *pstr,const vmp_char *fmt,...);
 */
 vmp_size str_cwrite(vmp::str *pstr,const vmp_char *fmt,...);
 
+//! Convert the input char to lowercase
+/*!
+    @param c input char
+    @return lowercase char
+*/
+vmp_char char_tolower(vmp_char c);
+
+//! Convert the input char to uppercase
+/*!
+    @param c input char
+    @return uppercase char
+*/
+vmp_char char_toupper(vmp_char c);
+
+//! Convert the input string to lowercase.
+/*!
+    @param str input string
+    @return lowercase string 
+*/
+vmp::str str_tolower(vmp::str str);
+
+//! Convert the input string to uppercase.
+/*!
+    @param str input string
+    @return uppercase string 
+*/
+vmp::str str_toupper(vmp::str str);
+
 //! Split string
 /*!
      @param str input string
@@ -69,49 +97,22 @@ vmp::str str_join(vmp::vector<vmp::str> list,vmp::str token);
 */
 vmp_bool byte_istype(vmp_byte byte,vmp::str type);
 
-//! Check if the byte input is an integer(DEPRECATED)
+//! Returns the n-th bit from a byte starting from the lowest
 /*!
-     @param byte input
-     @return true ok,otherwise false 
+    @param byte input byte
+    @param n bit number
+    @return 0 or 1
 */
-vmp_bool byte_isdigit(vmp_byte byte);
-
-//! Check if the byte input is a hexadecimal integer(DEPRECATED)
-/*!
-    @param byte input
-    @return true ok,otherwise false 
-*/
-vmp_bool byte_isxdigit(vmp_byte byte);
+vmp_uint byte_nbit(vmp_byte byte,vmp_uint n);
 
 //! Check if string characters are input type(see vmp::istype_wrap())
 /*!
     @param str input string
-    @param type type of data to be checked
+    @param type type of data to be checked(Types described in the vmp::istype_wrap() function and 'real' type describing real numbers)
     @return true if matching byte with type,otherwise false
 */
 vmp_bool str_istype(vmp::str str,vmp::str type);
 
-//! Check if the string input is an integer
-/*!
-     @param str string input
-     @return true ok,otherwise false 
-*/
-vmp_bool str_isdigit(vmp::str str);
-
-//! Check if the string input is a hexadecimal integer
-/*!
-     @param str string input
-     @return true ok,otherwise false 
-*/
-vmp_bool str_isxdigit(vmp::str str);
-
-//! Check if the string input is an real
-/*!
-     @param str string input
-     @return true ok,otherwise false 
-*/
-vmp_bool str_isreal(vmp::str str);
-
 //! Converts the string input to int
 /*!
      @param istr string input
@@ -306,6 +307,18 @@ vmp::vector<vmp::str> shlex_split(vmp::str args);
 */
 vmp::str shlex_join(vmp::vector<vmp::str> vargs);
 
+//! Input a string in format V1,V2,.. where V? == * (all values)
+//! V? == Single digit value , V? == DIGIT1-DIGIT2 interval value,
+//! V? == -DIGITMAX interval from minvalue to DIGITMAX, 
+//! DIGITMIN- interval from DIGITMIN to maxvalue example(2,3-5,12-,-11)
+/*!
+    @param istr string input
+    @param minvalue min value
+    @param maxvale max value
+    @return an ordered list of digit values without duplication or except in case of failue
+*/
+vmp::vector<vmp_index> str_toindex_list(vmp::str istr,vmp_index minvalue,vmp_index maxvalue);
+
 //! Extract tokens from strings
 class Strtok
 {
