@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 09/01/2020
+   Date last update: 03/04/2024
  */
 
 #include "vmp.h"
@@ -73,5 +73,24 @@ void Logger::write(vmp_byte facility,const vmp_char *fmt,...)
     write_s(facility,sfmt);
 }
 
+void Logger::rotate(vmp_index n)
+{
+    vmp::str src,dst;
+    if(loglevel_ != vmp::utils::LOG_NO)
+    {
+        for(vmp_index i=n-1;n>0;n--)
+        {
+            vmp::unicode::str_write(&src,"%s.%d",logname_,i);
+            vmp::unicode::str_write(&dst,"%s.%d",logname_,i+1);
+            if(vmp::fs::isfile(src))
+                vmp::copy_file(src,dst);
+        }
+        vmp::unicode::str_write(&dst,"%s.1",logname_);
+        if(vmp::fs::isfile(logname_))
+            vmp::copy_file(logname_,dst);
+         vmp::output_file_s(logname_,true,"");
+    }
+}
+
 }}}
 
