@@ -16,7 +16,7 @@
  * Author: Marco Guastella alias Vasta 
  * Web page:<www.ragnu.it> 
  * Email:<vasta@ragnu.it>
-   Date last update: 08/12/2020
+   Date last update: 29/11/2022
 */
  
 #include "xml.h"
@@ -30,21 +30,6 @@ void dom_parser_error(vmp_uint line,vmp::str error)
     vmp::except_s(err);
 }
 
-void attr_integrity(vmp_uint line,vmp::str name,vmp::str value)
-{
-    vmp::str error;
-    if(value.size() == 0)
-    {    
-        vmp::unicode::str_write(&error,"Attribute %s have empty value",name.c_str());
-        dom_parser_error(line,error);
-    }
-    if(!vmp::unicode::str_isword(value))
-    {    
-        vmp::unicode::str_write(&error,"Attribute name [%s] have value malformated",name.c_str());
-        dom_parser_error(line,error);
-    }
-}
- 
 Tag::Tag()
 {
     init(); 
@@ -69,7 +54,6 @@ void Tag::destroy_impl()
 {
 }
 
-
 void Tag::set_filepath(vmp::str filepath)
 {
      filepath_=filepath;
@@ -112,7 +96,6 @@ vmp::str Tag::get_text()
 
 void Tag::add_attr(vmp::str name,vmp::str value)
 {
-    attr_integrity(get_line(),name,value);
     try
     {
         attrs_.insert(name,value);    
