@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 18/03/2020
+#Date last Update : 05/04/2023
 
 import vmpconfig   as config
 import vmpbuild    as build
@@ -38,7 +38,7 @@ def description():
 def install():
     sys.config_create("{0}config_.h".format(sys.path(setup.path)),["/*Config file autogenerate from install*/\n","#ifndef VAMPIRIA_SOFTWARE_CFG_H\n\n#define VAMPIRIA_SOFTWARE_CFG_H 1\n","#define VAMPIRIA_DTDPATH \"vampiria.dtd\"\n","#endif"])
     build.cbuild(setup)
-    check.check_software([],["vmpproxy"])
+    check.check_modules([],["helper"])
     
 def uninstall():
   sys.config_remove("{0}config_.h".format(sys.path(setup.path)))
