@@ -16,7 +16,7 @@
 #Author: Marco Guastella alias Vasta
 #Web page:<www.ragnu.it>
 #Email: <vasta@ragnu.it>
-#Date last Update : 10/10/2023
+#Date last Update : 09/04/2024
 
 import vmplib    as lib
 import vmppylib  as pylib
@@ -35,17 +35,9 @@ db0.libs=[('sqlite3','3.40.1')]
 db0.loptions=['`pkg-config sqlite3 --cflags --libs`']
 lib.clibs_[db0.name]=db0
 
-xterm0=lib.clib()
-xterm0.name='xterm0'
-xterm0.dependencies=['vmp']
-xterm0.pkg=True
-xterm0.files=[('xterm/',['xterm'])]
-xterm0.cmd=['xterm -h']
-lib.clibs_[xterm0.name]=xterm0
-
 rawnet3=lib.clib()
 rawnet3.name='rawnet3'
-rawnet3.dependencies=['vmp','packet','event','net']
+rawnet3.dependencies=['vmp','packet','event']
 rawnet3.pkg=True
 rawnet3.files=[('rawnet/',['arpui','lib','rawnet','rawevent','rawui'])]
 rawnet3.libs=[('libpcap','1.10.3')]
@@ -53,15 +45,15 @@ rawnet3.coptions=['`pkg-config --cflags libpcap`']
 rawnet3.loptions=['`pkg-config --libs  libpcap`']
 lib.clibs_[rawnet3.name]=rawnet3
 
-openssl3=lib.clib()
-openssl3.name='openssl3'
-openssl3.dependencies=['vmp','net','event','json','db0']
-openssl3.pkg=True
-openssl3.cmd=['openssl version','chmod --version','cp --version']
-openssl3.files=[('openssl/',['lib','hash','openssl','x509','pkey','sslevent','sslui']),('openssl/ctx/',['ctx','base','https','peer']),('openssl/jrp/',['cb','jrp','jrpevent'])]
-openssl3.libs=[('openssl','3.0.9')]
-openssl3.loptions=['`pkg-config --libs  openssl`']
-lib.clibs_[openssl3.name]=openssl3
+openssl4=lib.clib()
+openssl4.name='openssl4'
+openssl4.dependencies=['vmp','net','event','json','db0']
+openssl4.pkg=True
+openssl4.cmd=['openssl version','chmod --version','cp --version']
+openssl4.files=[('openssl/',['eventssl','eventp2p','eventjrp','lib','hash','openssl','pkey','ssl','x509']),('openssl/ctx/',['ctx','base','https','peer']),('openssl/cb/',['sslcb','p2pcb','jrpcb'])]
+openssl4.libs=[('openssl','3.0.9')]
+openssl4.loptions=['`pkg-config --libs  openssl`']
+lib.clibs_[openssl4.name]=openssl4
 
 vmp_db0=pylib.pylib()
 vmp_db0.name='vmp_db0'
@@ -72,29 +64,14 @@ vmp_db0.setup.files=[('./',['db_'])]
 vmp_db0.setup.dependencies=['pylib','db0']
 pylib.pylibs_[vmp_db0.name]=vmp_db0
 
-vmp_xterm0=pylib.pylib()
-vmp_xterm0.name='vmp_xterm0'
-vmp_xterm0.dependencies=[]
-vmp_xterm0.pkg=True
-vmp_xterm0.cbuild()
-vmp_xterm0.setup.files=[('./',['xterm_'])]
-vmp_xterm0.setup.dependencies=['pylib','xterm0','vmp']
-pylib.pylibs_[vmp_xterm0.name]=vmp_xterm0
-
-vmp_gui0=pylib.pylib()
-vmp_gui0.name='vmp_gui0'
-vmp_gui0.dependencies=[]
-vmp_gui0.pkg=True
-pylib.pylibs_[vmp_gui0.name]=vmp_gui0
-
-vmp_openssl3=pylib.pylib()
-vmp_openssl3.name='vmp_openssl3'
-vmp_openssl3.dependencies=['vmp','vmp_net','vmp_event']
-vmp_openssl3.pkg=True
-vmp_openssl3.cbuild()
-vmp_openssl3.setup.files=[('./',['openssl_','hash_','pkey_','x509_','sslui_','ctx_','jrp_'])]
-vmp_openssl3.setup.dependencies=['pylib','openssl3']
-pylib.pylibs_[vmp_openssl3.name]=vmp_openssl3
+vmp_openssl4=pylib.pylib()
+vmp_openssl4.name='vmp_openssl4'
+vmp_openssl4.dependencies=['vmp','vmp_net','vmp_event','vmp_plugin','vmp_json']
+vmp_openssl4.pkg=True
+vmp_openssl4.cbuild()
+vmp_openssl4.setup.files=[('./',['openssl_','hash_','pkey_','ctx_','ssl_','x509_'])]
+vmp_openssl4.setup.dependencies=['pylib','openssl4']
+pylib.pylibs_[vmp_openssl4.name]=vmp_openssl4
 
 vmp_rawnet3=pylib.pylib()
 vmp_rawnet3.name='vmp_rawnet3'
